@@ -5,12 +5,14 @@ import unittest
 class NVD3TemplateTagsTestCase(unittest.TestCase):
 
     def testPiechart(self):
-        xdata = ["Apple", "Apricot", "Avocado", "Banana", "Boysenberries", "Blueberries", "Dates", "Grapefruit", "Kiwi", "Lemon"]
+        xdata = ["Apple", "Apricot", "Avocado", "Banana", "Boysenberries", "Blueberries",
+                 "Dates", "Grapefruit", "Kiwi", "Lemon"]
         ydata = [52, 48, 160, 94, 75, 71, 490, 82, 46, 17]
         chartdata = {'x': xdata, 'y': ydata}
         charttype = "pieChart"
+        extra = {'y_is_date': False}
 
-        self.assertTrue(load_chart(charttype, chartdata, 'container', y_is_date=False))
+        self.assertTrue(load_chart(charttype, chartdata, 'container', extra))
         self.assertTrue(include_container('container', height=400, width=600))
 
 
